% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AQSAPI.R
\name{aqs_transactionsample_by_site}
\alias{aqs_transactionsample_by_site}
\title{aqs_transactionsample_by_site}
\usage{
aqs_transactionsample_by_site(
  parameter,
  bdate,
  edate,
  stateFIPS,
  countycode,
  sitenum,
  return_header = FALSE
)
}
\arguments{
\item{parameter}{a character list or a single character string
which represents the parameter code of the air
pollutant related to the data being requested.}

\item{bdate}{a R date object which represents that begin date of the data
selection. Only data on or after this date will be returned.}

\item{edate}{a R date object which represents that end date of the data
selection. Only data on or before this date will be returned.}

\item{stateFIPS}{a R character object which represents the 2 digit state
FIPS code (with leading zero) for the state being
requested. @seealso \code{\link[=aqs_states]{aqs_states()}} for the list of
available FIPS codes.}

\item{countycode}{a R character object which represents the 3 digit state
FIPS code for the county being requested (with leading
zero(s)). @seealso \code{\link[=aqs_counties_by_state]{aqs_counties_by_state()}} for the
list of available county codes for each state.}

\item{sitenum}{a R character object which represents the 4 digit site number
(with leading zeros) within the county and state being
requested.}

\item{return_header}{If FALSE (default) only returns data requested.
If TRUE returns a AQSAPI_v2 object which is a two
item list that contains header information returned
from the API server mostly used for debugging
purposes in addition to the data requested.}
}
\value{
a tibble or an AQS_Data Mart_APIv2 S3 object of transaction sample
(raw) data in the AQS submission transaction format (RD)
corresponding to the inputs provided.
}
\description{
\lifecycle{stable}
Returns transactionsample data - aggregated by site
in the AQS Submission Transaction Format (RD) sample (raw) data for
a parameter code aggregated by matching input parameter, sitenum,
countycode and stateFIPS provided for bdate - edate time frame.
Includes data both in submitted and standard units
}
\note{
The AQS API only allows for a single year of transactiondata to be
retrieved at a time. This function conveniently extracts date
information from the bdate and edate parameters then makes repeated
calls to the AQSAPI retrieving a maximum of one calendar year of
data at a time. Each calendar year of data requires a separate API
call so multiple years of data will require multiple API calls.
As the number of years of data being requested increases so does the
length of time that it will take to retrieve results. There is also a
5 second wait time inserted between successive API calls to prevent
overloading the API server. This operation has a linear run time of
/(Big O notation: O/(n + 5 seconds/)/).
}
\examples{
#Returns a AQS_Data Mart_APIv2 S3 object of the returns
         \dontrun{ #   returns all ozone transaction data for the
                   #   Millbrook School site (#0014) in Wake County, NC for
                   #   June 18, 2017
                   aqs_transactionsample_by_site(parameter = "44201",
                                                 bdate = as.Date("20170618",
                                                         format = "\%Y\%m\%d"),
                                                 edate = as.Date("20170618",
                                                          format = "\%Y\%m\%d"),
                                                 stateFIPS = "37",
                                                 countycode = "183",
                                                 sitenum = "0014"
                                                 )
                 }
}
\seealso{
Other Aggregate _by_site functions: 
\code{\link{aqs_annualsummary_by_site}()},
\code{\link{aqs_dailysummary_by_site}()},
\code{\link{aqs_monitors_by_site}()},
\code{\link{aqs_qa_blanks_by_site}()},
\code{\link{aqs_qa_collocated_assessments_by_site}()},
\code{\link{aqs_qa_flowrateaudit_by_site}()},
\code{\link{aqs_qa_flowrateverification_by_site}()},
\code{\link{aqs_qa_one_point_qc_by_site}()},
\code{\link{aqs_qa_pep_audit_by_site}()},
\code{\link{aqs_sampledata_by_site}()},
\code{\link{aqs_services_by_site}()}
}
\concept{Aggregate _by_site functions}
